gtk+ r21953 - in trunk: . gtk



Author: matthiasc
Date: Sun Dec 28 06:58:09 2008
New Revision: 21953
URL: http://svn.gnome.org/viewvc/gtk+?rev=21953&view=rev

Log:
2008-12-28  Matthias Clasen  <mclasen redhat com>

        * gtk/gtkhsv.c:
        * gtk/gtkwidget.c:
        * gtk/gtkaccelgroup.c: Documentation fixes

        * gtk/gtkstatusicon.c:
        * gtk/gtkentry.c:
        * gtk/gtkeditable.[hc]: Make parameter names match to make gtk-doc
        happy.



Modified:
   trunk/ChangeLog
   trunk/gtk/gtkaccelgroup.c
   trunk/gtk/gtkeditable.c
   trunk/gtk/gtkentry.c
   trunk/gtk/gtkhsv.c
   trunk/gtk/gtkstatusicon.c
   trunk/gtk/gtkwidget.c

Modified: trunk/gtk/gtkaccelgroup.c
==============================================================================
--- trunk/gtk/gtkaccelgroup.c	(original)
+++ trunk/gtk/gtkaccelgroup.c	Sun Dec 28 06:58:09 2008
@@ -834,7 +834,6 @@
  *                 to activate the accelerator.
  * @accel_key:     accelerator keyval from a key event
  * @accel_mods:    keyboard state mask from a key event
- * @returns:       %TRUE if the accelerator was handled, %FALSE otherwise
  * 
  * Finds the first accelerator in @accel_group 
  * that matches @accel_key and @accel_mods, and
@@ -867,7 +866,6 @@
  *                 to activate the accelerator.
  * @accel_key:     accelerator keyval from a key event
  * @accel_mods:    keyboard state mask from a key event
- * @returns:       %TRUE if the accelerator was handled, %FALSE otherwise
  * 
  * Finds the first accelerator in any #GtkAccelGroup attached
  * to @object that matches @accel_key and @accel_mods, and

Modified: trunk/gtk/gtkeditable.c
==============================================================================
--- trunk/gtk/gtkentry.c	(original)
+++ trunk/gtk/gtkentry.c	Sun Dec 28 06:58:09 2008
@@ -6180,7 +6180,7 @@
 /**
  * gtk_entry_set_position:
  * @entry: a #GtkEntry
- * @position:  the position of the cursor. The cursor is displayed
+ * @position: the position of the cursor. The cursor is displayed
  *    before the character with the given (base 0) index in the widget. 
  *    The value must be less than or equal to the number of characters 
  *    in the widget. A value of -1 indicates that the position should
@@ -6193,7 +6193,7 @@
  */
 void
 gtk_entry_set_position (GtkEntry *entry,
-			gint       position)
+			gint      position)
 {
   g_return_if_fail (GTK_IS_ENTRY (entry));
 
@@ -6892,7 +6892,7 @@
 /**
  * gtk_entry_set_icon_from_pixbuf:
  * @entry: a #GtkEntry
- * @position: Icon position
+ * @icon_pos: Icon position
  * @pixbuf: A #GdkPixbuf, or %NULL
  *
  * Sets the icon shown in the specified position using a pixbuf.
@@ -6949,7 +6949,7 @@
 /**
  * gtk_entry_set_icon_from_stock:
  * @entry: A #GtkEntry
- * @position: Icon position
+ * @icon_pos: Icon position
  * @stock_id: The name of the stock item, or %NULL
  *
  * Sets the icon shown in the entry at the specified position from
@@ -7135,7 +7135,7 @@
 /**
  * gtk_entry_set_icon_activatable:
  * @entry: A #GtkEntry
- * @position: Icon position
+ * @icon_pos: Icon position
  * @activatable: %TRUE if the icon should be activatable
  *
  * Sets whether the icon is activatable.
@@ -7202,7 +7202,7 @@
 /**
  * gtk_entry_get_pixbuf:
  * @entry: A #GtkEntry
- * @position: Icon position
+ * @icon_pos: Icon position
  *
  * Retrieves the image used for the icon.
  *
@@ -7238,7 +7238,7 @@
 /**
  * gtk_entry_get_gicon:
  * @entry: A #GtkEntry
- * @position: Icon position
+ * @icon_pos: Icon position
  *
  * Retrieves the #GIcon used for the icon, or %NULL if there is
  * no icon or if the icon was set by some other method (e.g., by
@@ -7271,7 +7271,7 @@
 /**
  * gtk_entry_get_stock:
  * @entry: A #GtkEntry
- * @position: Icon position
+ * @icon_pos: Icon position
  *
  * Retrieves the stock id used for the icon, or %NULL if there is
  * no icon or if the icon was set by some other method (e.g., by
@@ -7304,7 +7304,7 @@
 /**
  * gtk_entry_get_icon_name:
  * @entry: A #GtkEntry
- * @position: Icon position
+ * @icon_pos: Icon position
  *
  * Retrieves the icon name used for the icon, or %NULL if there is
  * no icon or if the icon was set by some other method (e.g., by
@@ -7337,7 +7337,7 @@
 /**
  * gtk_entry_set_icon_sensitive:
  * @entry: A #GtkEntry
- * @position: Icon position
+ * @icon_pos: Icon position
  * @sensitive: Specifies whether the icon should appear
  *             sensitive or insensitive
  *

Modified: trunk/gtk/gtkhsv.c
==============================================================================
--- trunk/gtk/gtkhsv.c	(original)
+++ trunk/gtk/gtkhsv.c	Sun Dec 28 06:58:09 2008
@@ -1364,14 +1364,13 @@
 
 /**
  * gtk_hsv_new:
- * @void:
  *
  * Creates a new HSV color selector.
  *
  * Return value: A newly-created HSV color selector.
  *
  * Since: 2.14
- **/
+ */
 GtkWidget*
 gtk_hsv_new (void)
 {
@@ -1380,16 +1379,16 @@
 
 /**
  * gtk_hsv_set_color:
- * @hsv: An HSV color selector.
- * @h: Hue.
- * @s: Saturation.
- * @v: Value.
+ * @hsv: An HSV color selector
+ * @h: Hue
+ * @s: Saturation
+ * @v: Value
  *
- * Sets the current color in an HSV color selector.  Color component values must
- * be in the [0.0, 1.0] range.
+ * Sets the current color in an HSV color selector.
+ * Color component values must be in the [0.0, 1.0] range.
  *
  * Since: 2.14
- **/
+ */
 void
 gtk_hsv_set_color (GtkHSV *hsv,
 		   gdouble h,
@@ -1416,16 +1415,16 @@
 
 /**
  * gtk_hsv_get_color:
- * @hsv: An HSV color selector.
- * @h: Return value for the hue.
- * @s: Return value for the saturation.
- * @v: Return value for the value.
+ * @hsv: An HSV color selector
+ * @h: Return value for the hue
+ * @s: Return value for the saturation
+ * @v: Return value for the value
  *
- * Queries the current color in an HSV color selector.  Returned values will be
- * in the [0.0, 1.0] range.
+ * Queries the current color in an HSV color selector.
+ * Returned values will be in the [0.0, 1.0] range.
  *
  * Since: 2.14
- **/
+ */
 void
 gtk_hsv_get_color (GtkHSV *hsv,
                    double *h,
@@ -1450,14 +1449,14 @@
 
 /**
  * gtk_hsv_set_metrics:
- * @hsv: An HSV color selector.
- * @size: Diameter for the hue ring.
- * @ring_width: Width of the hue ring.
+ * @hsv: An HSV color selector
+ * @size: Diameter for the hue ring
+ * @ring_width: Width of the hue ring
  *
  * Sets the size and ring width of an HSV color selector.
  *
  * Since: 2.14
- **/
+ */
 void
 gtk_hsv_set_metrics (GtkHSV *hsv,
 		     gint    size,
@@ -1486,14 +1485,14 @@
 
 /**
  * gtk_hsv_get_metrics:
- * @hsv: An HSV color selector.
- * @size: Return value for the diameter of the hue ring.
- * @ring_width: Return value for the width of the hue ring.
+ * @hsv: An HSV color selector
+ * @size: Return value for the diameter of the hue ring
+ * @ring_width: Return value for the width of the hue ring
  *
  * Queries the size and ring width of an HSV color selector.
  *
  * Since: 2.14
- **/
+ */
 void
 gtk_hsv_get_metrics (GtkHSV *hsv,
 		     gint   *size,
@@ -1514,19 +1513,19 @@
 
 /**
  * gtk_hsv_is_adjusting:
- * @hsv:
+ * @hsv: A #GtkHSV 
  *
- * An HSV color selector can be said to be adjusting if multiple rapid changes
- * are being made to its value, for example, when the user is adjusting the
- * value with the mouse.  This function queries whether the HSV color selector
- * is being adjusted or not.
- *
- * Return value: TRUE if clients can ignore changes to the color value, since
- * they may be transitory, or FALSE if they should consider the color value
- * status to be final.
+ * An HSV color selector can be said to be adjusting if multiple rapid
+ * changes are being made to its value, for example, when the user is 
+ * adjusting the value with the mouse. This function queries whether 
+ * the HSV color selector is being adjusted or not.
+ *
+ * Return value: %TRUE if clients can ignore changes to the color value,
+ *     since they may be transitory, or %FALSE if they should consider
+ *     the color value status to be final.
  *
  * Since: 2.14
- **/
+ */
 gboolean
 gtk_hsv_is_adjusting (GtkHSV *hsv)
 {
@@ -1541,18 +1540,19 @@
 
 /**
  * gtk_hsv_to_rgb:
- * @h: Hue.
- * @s: Saturation.
- * @v: Value.
- * @r: Return value for the red component.
- * @g: Return value for the green component.
- * @b: Return value for the blue component.
- *
- * Converts a color from HSV space to RGB.  Input values must be in the
- * [0.0, 1.0] range; output values will be in the same range.
+ * @h: Hue
+ * @s: Saturation
+ * @v: Value
+ * @r: Return value for the red component
+ * @g: Return value for the green component
+ * @b: Return value for the blue component
+ *
+ * Converts a color from HSV space to RGB.
+ * Input values must be in the [0.0, 1.0] range; 
+ * output values will be in the same range.
  *
  * Since: 2.14
- **/
+ */
 void
 gtk_hsv_to_rgb (gdouble  h,
 		gdouble  s,
@@ -1579,18 +1579,19 @@
 
 /**
  * gtk_hsv_to_rgb:
- * @r: Red.
- * @g: Green.
- * @b: Blue.
- * @h: Return value for the hue component.
- * @s: Return value for the saturation component.
- * @v: Return value for the value component.
- *
- * Converts a color from RGB space to HSV.  Input values must be in the
- * [0.0, 1.0] range; output values will be in the same range.
+ * @r: Red
+ * @g: Green
+ * @b: Blue
+ * @h: Return value for the hue component
+ * @s: Return value for the saturation component
+ * @v: Return value for the value component
+ *
+ * Converts a color from RGB space to HSV.
+ * Input values must be in the [0.0, 1.0] range;
+ * output values will be in the same range.
  *
  * Since: 2.14
- **/
+ */
 void
 gtk_rgb_to_hsv (gdouble  r,
 		gdouble  g,

Modified: trunk/gtk/gtkstatusicon.c
==============================================================================
--- trunk/gtk/gtkstatusicon.c	(original)
+++ trunk/gtk/gtkstatusicon.c	Sun Dec 28 06:58:09 2008
@@ -2640,9 +2640,9 @@
 /**
  * gtk_status_icon_set_tooltip_text:
  * @status_icon: a #GtkStatusIcon
- * @tooltip_text: the contents of the tooltip for @status_icon
+ * @text: the contents of the tooltip for @status_icon
  *
- * Sets @tooltip_text as the contents of the tooltip.
+ * Sets @text as the contents of the tooltip.
  *
  * This function will take care of setting #GtkStatusIcon:has-tooltip to
  * %TRUE and of the default handler for the #GtkStatusIcon::query-tooltip
@@ -2655,7 +2655,7 @@
  */
 void
 gtk_status_icon_set_tooltip_text (GtkStatusIcon *status_icon,
-				  const gchar   *tooltip_text)
+				  const gchar   *text)
 {
   GtkStatusIconPrivate *priv;
 
@@ -2665,15 +2665,15 @@
 
 #ifdef GDK_WINDOWING_X11
 
-  gtk_widget_set_tooltip_text (priv->tray_icon, tooltip_text);
+  gtk_widget_set_tooltip_text (priv->tray_icon, text);
 
 #endif
 #ifdef GDK_WINDOWING_WIN32
-  if (tooltip_text == NULL)
+  if (text == NULL)
     priv->nid.uFlags &= ~NIF_TIP;
   else
     {
-      WCHAR *wcs = g_utf8_to_utf16 (tooltip_text, -1, NULL, NULL, NULL);
+      WCHAR *wcs = g_utf8_to_utf16 (text, -1, NULL, NULL, NULL);
 
       priv->nid.uFlags |= NIF_TIP;
       wcsncpy (priv->nid.szTip, wcs, G_N_ELEMENTS (priv->nid.szTip) - 1);
@@ -2685,7 +2685,7 @@
       g_warning ("%s:%d:Shell_NotifyIconW(NIM_MODIFY) failed", __FILE__, __LINE__-1);
 
   g_free (priv->tooltip_text);
-  priv->tooltip_text = g_strdup (tooltip_text);
+  priv->tooltip_text = g_strdup (text);
 #endif
 #ifdef GDK_WINDOWING_QUARTZ
   QUARTZ_POOL_ALLOC;
@@ -2693,7 +2693,7 @@
   QUARTZ_POOL_RELEASE;
 
   g_free (priv->tooltip_text);
-  priv->tooltip_text = g_strdup (tooltip_text);
+  priv->tooltip_text = g_strdup (text);
 #endif
 }
 

Modified: trunk/gtk/gtkwidget.c
==============================================================================
--- trunk/gtk/gtkwidget.c	(original)
+++ trunk/gtk/gtkwidget.c	Sun Dec 28 06:58:09 2008
@@ -8147,12 +8147,11 @@
   gdk_event_free (event);
 }
 
-/**
+/*
  * _gtk_widget_is_pointer_widget:
  * @widget: a #GtkWidget
  *
  * Returns %TRUE if the pointer window belongs to @widget.
- *
  */
 gboolean
 _gtk_widget_is_pointer_widget (GtkWidget *widget)
@@ -8174,7 +8173,7 @@
   return FALSE;
 }
 
-/**
+/*
  * _gtk_widget_synthesize_crossing:
  * @from: the #GtkWidget the virtual pointer is leaving.
  * @to: the #GtkWidget the virtual pointer is moving to.
@@ -8439,7 +8438,7 @@
     }
 }
 
-/**
+/*
  * _gtk_widget_get_aux_info:
  * @widget: a #GtkWidget
  * @create: if %TRUE, create the structure if it doesn't exist
@@ -8448,7 +8447,7 @@
  * 
  * Return value: the #GtkAuxInfo structure for the widget, or
  *    %NULL if @create is %FALSE and one doesn't already exist.
- **/
+ */
 GtkWidgetAuxInfo*
 _gtk_widget_get_aux_info (GtkWidget *widget,
 			  gboolean   create)



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/gtk/gtkeditable.c	(original)
+++ trunk/gtk/gtkeditable.c	Sun Dec 28 06:58:09 2008
@@ -142,10 +142,10 @@
 /**
  * gtk_editable_get_chars:
  * @editable: a #GtkEditable
  * @start: start of text
  * @end: end of text
  *
  * Retreives the content of the editable between @start and @end.
  * Note that positions are specified in characters, not bytes.
  *
  * Return value: a pointer to the contents of the widget as a
@@ -154,12 +154,12 @@
  **/
 gchar *    
 gtk_editable_get_chars (GtkEditable *editable,
-			gint         start,
-			gint         end)
+			gint         start_pos,
+			gint         end_pos)
 {
   g_return_val_if_fail (GTK_IS_EDITABLE (editable), NULL);
 
-  return GTK_EDITABLE_GET_CLASS (editable)->get_chars (editable, start, end);
+  return GTK_EDITABLE_GET_CLASS (editable)->get_chars (editable, start_pos, end_pos);
 }
 
 /**
@@ -256,21 +256,21 @@
 /**
  * gtk_editable_select_region:
  * @editable: a #GtkEditable
  * @start: start of region
  * @end: end of region
  *
  * Selects the text between @start and @end. Both @start and @end are
  * relative to the start of the content. Note that positions are specified
  * in characters, not bytes.
  **/
 void
 gtk_editable_select_region (GtkEditable *editable,
-			    gint         start,
-			    gint         end)
+			    gint         start_pos,
+			    gint         end_pos)
 {
   g_return_if_fail (GTK_IS_EDITABLE (editable));
   
-  GTK_EDITABLE_GET_CLASS (editable)->set_selection_bounds (editable,  start, end);
+  GTK_EDITABLE_GET_CLASS (editable)->set_selection_bounds (editable, start_pos, end_pos);
 }
 
 /**
@@ -142,10 +142,10 @@
  * gtk_editable_get_chars:
  * @editable: a #GtkEditable
- * @start: start of text
- * @end: end of text
+ * @start_pos: start of text
+ * @end_pos: end of text
  *
@@ -142,10 +142,10 @@
  *
- * Retreives the content of the editable between @start and @end.
+ * Retreives the content of the editable between @start_pos and @end_pos.
  * Note that positions are specified in characters, not bytes.
  *
@@ -256,21 +256,21 @@
  * gtk_editable_select_region:
  * @editable: a #GtkEditable
- * @start: start of region
- * @end: end of region
+ * @start_pos: start of region
+ * @end_pos: end of region
  *
@@ -256,21 +256,21 @@
  *
- * Selects the text between @start and @end. Both @start and @end are
- * relative to the start of the content. Note that positions are specified
- * in characters, not bytes.
+ * Selects the text between @start_pos and @end_pos. Both @start_pos and 
+ * @end_pos are relative to the start of the content. Note that positions 
+ * are specified in characters, not bytes.
  **/
 void

Modified: trunk/gtk/gtkentry.c
==============================================================================